==> keybase-1.0.36.tar.gz: client-1.0.36/shared/login/signup/request-invite.js <==
// @flow
import {requestInvite, restartSignup} from '../../actions/signup'
import React, {Component} from 'react'
import Render from './request-invite.render'
import {connect} from 'react-redux'

type ContainerProps = {
  restartSignup: () => void,
  requestInvite: (email: string, name: string) => void,
  nameErrorText: ?string,
  emailErrorText: ?string,
  waiting: boolean,
  email?: ?string,
  name?: ?string,
}

type State = {
  email: string,
  name: string,
}

class RequestInvite extends Component<ContainerProps, State> {
  state: State

  constructor(props: ContainerProps) {
    super(props)

    this.state = {
      email: this.props.email || '',
      name: this.props.name || '',
    }
  }

  render() {
    return (
      <Render
        name={this.state.name}
        nameChange={name => this.setState({name})}
        email={this.state.email}
        emailChange={email => this.setState({email})}
        emailErrorText={this.props.emailErrorText}
        nameErrorText={this.props.nameErrorText}
        onBack={this.props.restartSignup}
        onSubmit={() => this.props.requestInvite(this.state.email, this.state.name)}
        waiting={this.props.waiting}
      />
    )
  }
}

export default connect(
  state => ({
    emailErrorText: state.signup.emailError,
    nameErrorText: state.signup.nameError,
    waiting: state.signup.waiting,
  }),
  (dispatch: Dispatch<*>) => ({
    requestInvite: (email, name) => dispatch(requestInvite(email, name)),
    restartSignup: () => dispatch(restartSignup()),
  })
)(RequestInvite)

==> keybase-1.0.41.tar.gz: client-1.0.41/shared/login/signup/request-invite.js <==
// @flow
import {requestInvite, restartSignup} from '../../actions/signup'
import React, {Component} from 'react'
import Render from './request-invite.render'
import {connect, type TypedState} from '../../util/container'

type ContainerProps = {
  restartSignup: () => void,
  requestInvite: (email: string, name: string) => void,
  nameErrorText: ?string,
  emailErrorText: ?string,
  waiting: boolean,
  email?: ?string,
  name?: ?string,
}

type State = {
  email: string,
  name: string,
}

class RequestInvite extends Component<ContainerProps, State> {
  state: State

  constructor(props: ContainerProps) {
    super(props)

    this.state = {
      email: this.props.email || '',
      name: this.props.name || '',
    }
  }

  render() {
    return (
      <Render
        name={this.state.name}
        nameChange={name => this.setState({name})}
        email={this.state.email}
        emailChange={email => this.setState({email})}
        emailErrorText={this.props.emailErrorText}
        nameErrorText={this.props.nameErrorText}
        onBack={this.props.restartSignup}
        onSubmit={() => this.props.requestInvite(this.state.email, this.state.name)}
        waiting={this.props.waiting}
      />
    )
  }
}

const mapStateToProps = (state: TypedState) => ({
  emailErrorText: state.signup.emailError,
  nameErrorText: state.signup.nameError,
  waiting: state.signup.waiting,
})

const mapDispatchToProps = (dispatch: Dispatch<*>) => ({
  requestInvite: (email, name) => dispatch(requestInvite(email, name)),
  restartSignup: () => dispatch(restartSignup()),
})
export default connect(mapStateToProps, mapDispatchToProps)(RequestInvite)
